@@ -7,7 +7,7 @@ use strict;
 
 package XML::Compile::SOAP;
 use vars '$VERSION';
-$VERSION = '3.15';
+$VERSION = '3.16';
 
 
 use Log::Report          'xml-compile-soap';
@@ -15,7 +15,7 @@ use XML::Compile         ();
 use XML::Compile::Util   qw(SCHEMA2001 SCHEMA2001i pack_type
    unpack_type type_of_node);
 use XML::Compile::Cache  ();
-use XML::Compile::SOAP::Util qw/:xop10/;
+use XML::Compile::SOAP::Util qw/:xop10 SOAP11ENC/;
 
 use Time::HiRes          qw/time/;
 use MIME::Base64         qw/decode_base64/;
@@ -280,6 +280,8 @@ sub _writer_body_rpclit_hook($$$$$)
 
         my $proc = $doc->createElement($proc);
         $proc->setNamespace($proc_ns, $prefix, 0);
+        $proc->setAttribute("SOAP-ENV:encodingStyle", SOAP11ENC);
+
         $proc->appendChild($_) for @pchilds;
 
         my $node = $doc->createElement($tag);
